@@ -1,6 +1,9 @@
 package Dist::Zilla::PluginBundle::FLORA;
 BEGIN {
-  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.01';
+  $Dist::Zilla::PluginBundle::FLORA::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $Dist::Zilla::PluginBundle::FLORA::VERSION = '0.02';
 }
 # ABSTRACT: Build your distributions like FLORA does
 
@@ -150,11 +153,18 @@ method configure {
         MetaJSON
     ));
 
-    $self->add_plugins([ 'MetaResources' => {
-        repository => $self->_repository_url,
-        bugtracker => $self->bugtracker_url,
-        homepage   => $self->homepage_url,
-    }]);
+    $self->add_plugins(
+        [MetaResources => {
+            repository => $self->_repository_url,
+            bugtracker => $self->bugtracker_url,
+            homepage   => $self->homepage_url,
+        }],
+        [Authority => {
+            authority   => 'cpan:FLORA',
+            do_metadata => 1,
+        }]
+    );
+
 
     $self->is_task
         ? $self->add_plugins('TaskWeaver')
